Fast Network Simulation Setup (FNSS) — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- FNSS 0.5.0 documentation »

# Fast Network Simulation Setup (FNSS)

This is the documentation of the FNSS core library. It is a Python library providing a set of features allowing to simplify the setup of a network experiment. These features include the ability to:

- Parse a topology from a dataset, a topology generator or generate it according to a number of synthetic models
- Apply link capacity, link weights, link delays and buffer sizes
- Deploy application stacks
- Generate traffic matrices
- Generate event schedules

The core libary in addition to the features listed above, contains adapters to export generated scnearios to a the following network simulators or emulators: ns-2, Mininet and Autonetkit. Generated expriment scenarios (i.e. topologies, event schedules and traffic matrices) can be saved into XML files and then imported by libraries written in other languages. Currently, FNSS provides generic Java and C++ libraries as well as a C++ library specific for the ns-3 simulator. These libraries can be downloaded from the FNSS website.

The FNSS core library is released under the terms of the BSD license.

If you use FNSS for your paper, please cite the following publication:

> Lorenzo Saino, Cosmin Cocora and George Pavlou, A Toolchain for Symplifying Network Simulation Setup, in Proceedings of the 6th International ICST Conference on Simulation Tools and Techniques (SIMUTOOLS ‘13), Cannes, France, March 2013

The BibTeX entry is:

    @inproceedings{fnss,
         author = {Saino, Lorenzo and Cocora, Cosmin and Pavlou, George},
         title = {A Toolchain for Simplifying Network Simulation Setup},
         booktitle = {Proceedings of the 6th International ICST Conference on Simulation Tools and Techniques},
         series = {SIMUTOOLS '13},
         year = {2013},
         location = {Cannes, France},
         numpages = {10},
         publisher = {ICST (Institute for Computer Sciences, Social-Informatics and Telecommunications Engineering)},
         address = {ICST, Brussels, Belgium, Belgium},
    }

## Contents

- Architecture
- Install
  - Quick install
    - Ubuntu (version 12.04+)
    - Other operating systems
  - Installing from source
    - Source archive file
    - Git repository
  - Requirements
    - Python
    - Required packages
      - NetworkX (version >= 1.6)
      - NumPy (version >= 1.4)
      - Mako (version >= 0.4)
- API Reference
  - Classes
    - Topology
    - DirectedTopology
    - DatacenterTopology
    - TrafficMatrix
    - TrafficMatrixSequence
    - EventSchedule
  - Functions
    - `netconfig` package
      - `buffers` module
      - `capacities` module
      - `delays` module
      - `nodeconfig` module
      - `weights` module
    - `traffic` package
      - `eventscheduling` module
      - `trafficmatrices` module
    - `topologies` package
      - `datacenter` module
      - `parsers` module
      - `randmodels` module
      - `simplemodels` module
      - `topology` module
    - `adapters` package
      - `autonetkit` module
      - `mn` module
      - `ns2` module
  - Scripts
    - mn-fnss
    - fnss-troubleshoot
- Examples
  - Rocketfuel Tm
  - Mininet Dumbbell
  - Ns2
  - Gen Event Schedule
  - Mininet Datacenter
  - Dynamic Topology
  - Datacenter

## Indices and tables

- Index
- Module Index

### Navigation

- index
- modules |
- modules |
- next |
- FNSS 0.5.0 documentation »